@@ -76,3 +76,12 @@ class coupon(base):
         data = {"id": _id}
         response = self.request(api_name, data, method="POST")
         return self.response(response)
+
+class couponIssue(base):
+    def __init__(self, token):
+        super().__init__(token)
+
+    def create(self, data):
+        api_name = "manager/coupon_issue/add"
+        return self.request(api_name, data, method="POST")
+    
\ No newline at end of file
