@@ -21,9 +21,9 @@ class base:
         }
         kwargs["headers"] = headers
         response = requests.request(method=method, url=api_address, **kwargs)
-        # logger.debug(response.json())
         if response.status_code == 200:
             return self.response(response.json())
+        logger.error(response.json())
 
     def response(self, response_json):
         status_code = response_json.get("status_code")
